# simublocks

Simublocks is a python program, made with Tkinter, for simulating dynamic systems.

This project is still under construction. Please feel free to contribute.

## Installation

Install dependencies

    sudo apt install python3 python3-pip python3-tk

Download and run simublocks

    pip3 install simublocks
    simublocks

If a new version is available, upgrade simublocks with

    pip3 install simublocks --upgrade

## Screenshots

<p align="center">
  <img src="https://raw.githubusercontent.com/bentoavb/simublocks/master/images/img7.png" width="800" />
</p>

<p align="center">
  <img alt="" src="https://raw.githubusercontent.com/bentoavb/simublocks/master/images/img2.png" width="350" />
  <img alt="" src="https://raw.githubusercontent.com/bentoavb/simublocks/master/images/img3.png" width="350" />
</p>

 

## License

MIT License

Copyright (c) 2020 Anderson Vitor Bento